<?php
	/**************************************************************************
	
	XML Generator for SlideShowPro
	Brad Daily - slideshowpro.net
	
	For instructions, see the wiki:
	http://wiki.slideshowpro.net/SSPExtras/PhpXmlBuilder
	
	This script is governed by the following license:
	http://creativecommons.org/licenses/by-nc-sa/3.0/us/
	
	**************************************************************************/
	
	/*
		CONFIGURATION
	*/
	
	// Name of the folder in each album's folder that contains the full size imagery
	$large_folder = 'lg';
	
	// Name of the folder in each album's folder that contains the thumbnails
	$thumb_folder = 'tn';
	
	// Name of your album preview image. Should be placed at the root of each album's folder. (Optional)
	$album_preview_name = 'albumPreview.jpg';
	
	/*
		END CONFIGURATION 
		(DO NOT EDIT BELOW THIS LINE UNLESS YOU KNOW WHAT YOU ARE DOING)
	*/
	
	// Set up paths
	define('DS', DIRECTORY_SEPARATOR);
	$dir = dirname(__FILE__);
	$server = 'http://' . $_SERVER['HTTP_HOST'];
	$rel_path = str_replace('images.php', '', $_SERVER['PHP_SELF']);
	$path = $server . $rel_path;
	$iptc = is_callable('iptcparse');
	
	// Find all folders in this directory
	$albums = array();

	$d = dir($dir);
	while (false !== ($folder = $d->read())) {
		if ($folder != '.' && $folder != '..' && is_dir($dir . DS . $folder . DS . $large_folder)) {
			$albums[] = $folder;
		}
	}
	$d->close();
	
	// Start writing XML
	$o = '<?xml version="1.0" encoding="utf-8"?>' . "\n<gallery>\n";
	
	// Cycle through albums
	foreach($albums as $album) {
		// Path variables
		$loc_path = $path . $album . '/';
		$full_path = $dir . DS . $album;
		
		// Find images in the large folder
		$images = array();
		$d2 = dir($full_path . DS . $large_folder);
		while (false !== ($image = $d2->read())) {
			if (eregi('.jpg|.gif|.png|.swf|.flv', $image)) {
				$images[] = $image;
			} 
		}
		$d2->close();
		
		// Only write the album to XML if there are images
		if (!empty($images)) {
			natcasesort($images);
			// Pretty up the title
			$title = ucwords(preg_replace('/_|-/', ' ', $album));

			// See if there is an album thumb present, if so add it in
			if (file_exists($full_path . DS . $album_preview_name)) {
				$atn = ' tn="' . $loc_path . $album_preview_name . '"';
			} else {
				$atn = '';
			}
			
			// Only write tnPath if that folder exists
			if (is_dir($full_path . DS . $thumb_folder)) {
				$tn = ' tnpath="' . $loc_path . $thumb_folder . '/"';
			}
			
			// Album tag
			$o .= "\t" . '<album title="' . $title . '" description="" id="' . $title . '" lgpath="' . $loc_path . $large_folder . '/"' . $tn . $atn . '>' . "\n";
			
			// Cycle through images, adding tag for each to XML
			foreach($images as $i) {
				$link = $caption = $title = '';
				
				if ($iptc) {
					$file = $full_path . DS . $large_folder . DS . $i;
					$path_info = pathinfo($file);
					$extensions = array('jpg', 'jpeg', 'gif', 'png');
					if (in_array(strtolower($path_info['extension']), $extensions)) {
						getimagesize($file, $info);
						if (!empty($info['APP13'])) {
							$iptc = iptcparse($info['APP13']);
							if (isset($iptc['2#005'])) {
								$title = $iptc['2#005'];
								if (is_array($title)) {
									$title = htmlentities($title[0], ENT_COMPAT);
								}
							}
							if (isset($iptc['2#120'])) {
								$caption = $iptc['2#120'];
								if (is_array($caption)) {
									$caption = htmlentities($caption[0], ENT_COMPAT);
								}
							}
						}
					}
				}
				
				if (isset($_GET['link'])) { $link = $loc_path . $large_folder . '/' . $i; }
				$o .= "\t\t" . '<img src="' . $i . '" title="' . $title . '" caption="' . $caption . '" link="' . $link . '" />' . "\n"; 
			}
			
			// Close the album tag
			$o .= "\t</album>\n";
		}
	}
	
	// Close gallery tag, set header and output XML
	$o .= "</gallery>";
	header('Content-type: text/xml'); 
	die($o);
?>